@@ -48,6 +48,7 @@ from mypy.nodes import (
     ARG_POS,
     ARG_OPT,
     FUNC_NO_INFO,
+    NameExpr,
 )
 
 from collections import defaultdict
@@ -258,17 +259,26 @@ class ZopeInterfacePlugin(Plugin):
         self, fullname: str
     ) -> Optional[Callable[[ClassDefContext], None]]:
         # print(f"get_metaclass_hook: {fullname}")
-        return None
+        def analyze_metaclass(ctx: ClassDefContext) -> None:
+            metaclass = ctx.cls.metaclass
+            if not isinstance(metaclass, RefExpr):
+                return
+            info = metaclass.node
+            if not isinstance(info, TypeInfo):
+                return
+
+            expected = "zope.interface.interface.InterfaceClass"
+            if any(node.fullname == expected for node in info.mro):
+                self.log(f"Found zope interface: {ctx.cls.fullname}")
+                md = self._get_metadata(ctx.cls.info)
+                md["is_interface"] = True
+
+        return analyze_metaclass
 
     def get_base_class_hook(
         self, fullname: str
     ) -> Optional[Callable[[ClassDefContext], None]]:
         # print(f"get_base_class_hook: {fullname}")
-        def analyze_direct(classdef_ctx: ClassDefContext) -> None:
-            self.log(f"Found zope interface: {classdef_ctx.cls.fullname}")
-            md = self._get_metadata(classdef_ctx.cls.info)
-            md["is_interface"] = True
-
         def analyze_subinterface(classdef_ctx: ClassDefContext) -> None:
             # If one of the bases is an interface, this is also an interface
             if isinstance(classdef_ctx.reason, IndexExpr):
@@ -284,7 +294,7 @@ class ZopeInterfacePlugin(Plugin):
             base_name = reason.fullname
             if not base_name:
                 return
-            if '.' not in base_name:
+            if "." not in base_name:
                 # When class is inherited from a dynamic parameter, it will not
                 # have a fully-qualified name, so we cannot use api to look it
                 # up. Just give up in this case.
@@ -300,9 +310,6 @@ class ZopeInterfacePlugin(Plugin):
                 cls_md = self._get_metadata(cls_info)
                 cls_md["is_interface"] = True
 
-        if fullname == "zope.interface.interface.Interface":
-            return analyze_direct
-
         return analyze_subinterface
 
     def get_customize_class_mro_hook(
